from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Relay_SolidState = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'34.81-8240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'34.81-8240'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Finder_34.81'], 'footprint':'OptoDevice:Finder_34.81', 'keywords':'Photo-Triac Opto Triac', 'description':'', 'datasheet':'https://gfinder.findernet.com/public/attachments/34/EN/S34USAEN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\n34.81-8240\n\nPhoto-Triac Opto Triac', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'34.81-9024', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'34.81-9024'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Finder_34.81'], 'footprint':'OptoDevice:Finder_34.81', 'keywords':'NPN DC Optocoupler', 'description':'', 'datasheet':'http://www.us.liteon.com/downloads/LTV-817-827-847.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\n34.81-9024\n\nNPN DC Optocoupler', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH0213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH0213'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH0213\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH0213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH0213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH0213A\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH0223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH0223'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH0223\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH0223A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH0223A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH0223A\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ASSR-1218', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ASSR-1218'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-4_4.4x4.3mm_P2.54mm'], 'footprint':'Package_SO:SO-4_4.4x4.3mm_P2.54mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'https://docs.broadcom.com/docs/AV02-0173EN', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nASSR-1218\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CPC1002N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CPC1002N'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-4_3.8x4.1mm_P2.54mm'], 'footprint':'Package_SO:SOP-4_3.8x4.1mm_P2.54mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'http://www.ixysic.com/home/pdfs.nsf/www/CPC1002N.pdf/$file/CPC1002N.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nCPC1002N\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CPC1017N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CPC1017N'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-4_3.8x4.1mm_P2.54mm'], 'footprint':'Package_SO:SOP-4_3.8x4.1mm_P2.54mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'http://www.ixysic.com/home/pdfs.nsf/www/CPC1017N.pdf/$file/CPC1017N.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nCPC1017N\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FOD420', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FOD420'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FOD4218-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFOD420\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3011', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3011'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3011\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LCC110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LCC110'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'MOSFET Output Photorelay 1-Form-C', 'description':'', 'datasheet':'http://www.ixysic.com/home/pdfs.nsf/www/LCC110.pdf/$file/LCC110.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nLCC110\n\nMOSFET Output Photorelay 1-Form-C', 'pins':[
            Pin(num='1',name='nc',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='nc',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3010M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3010M'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3010M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3031M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3031M'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3031M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S102S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S102S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s102s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS102S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S102S02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S102S02'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s102s02_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS102S02\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP141G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP141G'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-5_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-5_4.4x3.6mm_P1.27mm', 'keywords':'OptoThyristor DC Optocoupler', 'description':'', 'datasheet':'http://datasheet.octopart.com/TLP141G(U,F)-Toshiba-datasheet-134958.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP141G\n\nOptoThyristor DC Optocoupler', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP160G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP160G'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'keywords':'Opto-Triac Opto Triac Random', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=16916&prodName=TLP160G', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP160G\n\nOpto-Triac Opto Triac Random', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP161G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP161G'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=16921&prodName=TLP161G', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP161G\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP175A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP175A'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=13665&prodName=TLP175A', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP175A\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP222A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP222A'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-4_W7.62mm'], 'footprint':'Package_DIP:DIP-4_W7.62mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=17036&prodName=TLP222A', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP222A\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP222A-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP222A-2'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Dual MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=17036&prodName=TLP222A', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP222A-2\n\nDual MOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '1', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3', '6', '5']}] }),
        Part(**{ 'name':'TLP3123', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3123'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-4_4.4x3.9mm_P2.54mm'], 'footprint':'Package_SO:SO-4_4.4x3.9mm_P2.54mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=10047&prodName=TLP3123', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3123\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP3542', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3542'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-5-6_W7.62mm'], 'footprint':'Package_DIP:DIP-5-6_W7.62mm', 'keywords':'photocouplers photorelay solidstate relay normally opened (1-Form-A)', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=1284&prodName=TLP3542', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3542\n\nphotocouplers photorelay solidstate relay normally opened (1-Form-A)', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP3543', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3543'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'photocouplers photorelay solidstate relay normally opened (1-Form-A)', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=12660&prodName=TLP3543', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3543\n\nphotocouplers photorelay solidstate relay normally opened (1-Form-A)', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'34.81-7048', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'34.81-7048'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Finder_34.81', 'OptoDevice:Finder_34.81'], 'footprint':'OptoDevice:Finder_34.81', 'keywords':'NPN DC Optocoupler', 'description':'', 'datasheet':'http://www.us.liteon.com/downloads/LTV-817-827-847.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\n34.81-7048\n\nNPN DC Optocoupler', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH1213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH1213'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH1213\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH1213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH1213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH1213A\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH1223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH1223'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH1223\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH1223A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH1223A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH1223A\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH2213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH2213'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH2213\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH2213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH2213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH2213A\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH2223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH2223'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH2223\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH2223A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH2223A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH2223A\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH3213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH3213'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH3213\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH3213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH3213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH3213A\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH3223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH3223'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH3223\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH3223A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH3223A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH3223A\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BC2213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BC2213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-8-7_6.4x9.7mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://wmsc.lcsc.com/wmsc/upload/file/pdf/v2/lcsc/2312161855_BC-BC2213A_C596512.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nBC2213A\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CPC1117N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CPC1117N'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-4_3.8x4.1mm_P2.54mm', 'Package_SO:SOP-4_3.8x4.1mm_P2.54mm'], 'footprint':'Package_SO:SOP-4_3.8x4.1mm_P2.54mm', 'keywords':'MOSFET Output Photorelay 1-Form-B NC', 'description':'', 'datasheet':'http://www.ixysic.com/home/pdfs.nsf/www/CPC1117N.pdf/$file/CPC1117N.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nCPC1117N\n\nMOSFET Output Photorelay 1-Form-B NC', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FOD4208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FOD4208'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FOD4218-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFOD4208\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FOD4216', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FOD4216'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FOD4218-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFOD4216\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FOD4218', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FOD4218'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FOD4218-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFOD4218\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3012', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3012'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3012\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3022', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3022'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3022\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3023', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3023'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3023\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3052', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3052'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3052\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3053', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3053'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3053\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HHG1D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HHG1D-1'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Relay_THT:Relay_NCR_HHG1D-1'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'ssr', 'description':'', 'datasheet':'https://ncr.hk/uploads/Relays/Solid_State_Relays/HHG1D-1.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nHHG1D-1\n\nssr', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LAA110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LAA110'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Dual MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'http://www.clare.com/home/pdfs.nsf/www/LAA110.pdf/$file/LAA110.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nLAA110\n\nDual MOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '8', '1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '6', '4', '5']}] }),
        Part(**{ 'name':'LBB110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LBB110'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Dual MOSFET Output Photorelay 1-Form-B', 'description':'', 'datasheet':'http://www.ixysic.com/home/pdfs.nsf/www/LBB110.pdf/$file/LBB110.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nLBB110\n\nDual MOSFET Output Photorelay 1-Form-B', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7', '2', '8']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3', '5', '6']}] }),
        Part(**{ 'name':'MOC3011M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3011M'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3011M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3012M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3012M'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3012M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3020M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3020M'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3020M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3021M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3021M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3021M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3022M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3022M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3022M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3023M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3023M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3023M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3032M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3032M'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3032M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3033M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3033M'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3033M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3041M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3041M'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3041M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3042M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3042M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3042M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3043M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3043M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3043M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3051M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3051M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3052M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3051M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3052M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3052M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3052M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3052M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3061M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3061M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3163M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3061M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3062M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3062M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3163M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3062M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3063M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3063M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3163M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3063M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3081M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3081M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3083M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3081M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3082M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3082M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3083M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3082M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3083M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3083M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3083M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3083M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3162M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3162M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3163M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3162M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3163M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3163M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3163M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3163M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S112S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S112S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s112s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS112S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S116S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S116S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s116s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS116S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S116S02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S116S02'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Relay_THT:Relay_NCR_HHG1D-1', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s116s02_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS116S02\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S202S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S202S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s102s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS202S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S202S02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S202S02'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Relay_THT:Relay_NCR_HHG1D-1', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s102s02_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS202S02\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S212S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S212S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s112s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS212S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S216S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S216S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s116s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS216S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S216S02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S216S02'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Relay_THT:Relay_NCR_HHG1D-1', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s116s02_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS216S02\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP148G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP148G'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-5_4.4x3.6mm_P1.27mm', 'Package_SO:MFSOP6-5_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-5_4.4x3.6mm_P1.27mm', 'keywords':'OptoThyristor DC Optocoupler', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=1019&prodName=TLP148G', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP148G\n\nOptoThyristor DC Optocoupler', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP160J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP160J'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'keywords':'Opto-Triac Opto Triac Random', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=16919&prodName=TLP160J', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP160J\n\nOpto-Triac Opto Triac Random', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP161J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP161J'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=4207&prodName=TLP161J', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP161J\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP3544', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3544'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'photocouplers photorelay solidstate relay normally opened (1-Form-A)', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=12661&prodName=TLP3544', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3544\n\nphotocouplers photorelay solidstate relay normally opened (1-Form-A)', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP3545', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3545'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'photocouplers photorelay solidstate relay normally opened (1-Form-A)', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=12663&prodName=TLP3545', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3545\n\nphotocouplers photorelay solidstate relay normally opened (1-Form-A)', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP3546', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3546'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'photocouplers photorelay solidstate relay normally opened (1-Form-A)', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=12671&prodName=TLP3546', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3546\n\nphotocouplers photorelay solidstate relay normally opened (1-Form-A)', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_NXP_HCS12 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'MC9S12DT256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S12DT256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'HCS12 MCU', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/fact-sheet/MC9S12DT256FS.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HCS12.kicad_sym\nMC9S12DT256\n\nHCS12 MCU', 'pins':[
            Pin(num='1',name='SS1/PWM3/KWP3/PP3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PT1/IOC1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='BF_PROK/TXCAN0/TXCAN4/SCK0/PM5',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='BF_PSYN/RXCAN0/RXCAN4/MOSI0/PM4',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='TX_BF/TXCAN1/TXCAN0/SS0/PM3',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='RX_BF/RXCAN1/RXCAN0/MISO0/PM2',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='TXCAN0/TXB/PM1',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='RXCAN0/RXB/PM0',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VSSX',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='VDDX',func=pin_types.PWRIN,unit=1),
            Pin(num='108',name='ECS/ROMCTL/PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PWM7/KWP7/PP7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PT2/IOC2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PWM6/KWP6/PP6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PWM5/KWP5/PP5',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PWM4/KWP4/PP4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PT3/IOC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PT4/IOC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PT5/IOC5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PT6/IOC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PT7/IOC7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='XADDR19/PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SCK1/PWM2/KWP2/PP2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XADDR18/PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='KWJ1/PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='KWJ0/PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='BKGD/TAGHI/MODC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='ADDR0/DATA0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='ADDR1/DATA1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='ADDR2/DATA2/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ADDR3/DATA3/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ADDR4/DATA4/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='ADDR5/DATA5/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='MOSI1/PWM1/KWP1/PP1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='ADDR6/DATA6/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='ADDR7/DATA7/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH7/KWH7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH6/KWH6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PH5/KWH5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PH4/KWH4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE7/NOACC/XCLKS',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE6/MODB',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE5/MODA',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE4/ECLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='MISO1/PWM0/KWP0/PP0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSR',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='XFC',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSSPLL',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='PH3/KWH3/SS1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='XADDR17/PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PH2/KWH2/SCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PH1/KWH1/MOSI1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PH0/KWH0/MISO1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE3/TAGLO/LSTRB',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE2/RW',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE1/IRQ',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='PE0/XIRQ',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='ADDR8/DATA8/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='ADDR9/DATA9/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='ADDR10/DATA10/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XADDR16/PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='ADDR11/DATA11/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='ADDR12/DATA12/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='ADDR13/DATA13/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='ADDR14/DATA14/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='ADDR15/DATA15/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VDD2',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='VSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='PAD00/AN00',func=pin_types.INPUT,unit=1),
            Pin(num='68',name='PAD08/AN08',func=pin_types.INPUT,unit=1),
            Pin(num='69',name='PAD01/AN01',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XADDR15/PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PAD09/AN09',func=pin_types.INPUT,unit=1),
            Pin(num='71',name='PAD02/AN02',func=pin_types.INPUT,unit=1),
            Pin(num='72',name='PAD10/AN10',func=pin_types.INPUT,unit=1),
            Pin(num='73',name='PAD03/AN03',func=pin_types.INPUT,unit=1),
            Pin(num='74',name='PAD11/AN11',func=pin_types.INPUT,unit=1),
            Pin(num='75',name='PAD04/AN04',func=pin_types.INPUT,unit=1),
            Pin(num='76',name='PAD12/AN12',func=pin_types.INPUT,unit=1),
            Pin(num='77',name='PAD05/AN05',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='PAD13/AN13',func=pin_types.INPUT,unit=1),
            Pin(num='79',name='PAD06/AN06',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XADDR14/PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PAD14/AN14',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='PAD07/AN07/ETRIG0',func=pin_types.INPUT,unit=1),
            Pin(num='82',name='PAD15/AN15/ETRIG1',func=pin_types.INPUT,unit=1),
            Pin(num='83',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='VRH',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='VRL',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='BF_PSLM/TXCAN4/PM7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='BF_PERR/RXCAN4/PM6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='RXD0/PS0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PT0/IOC0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='TXD0/PS1',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='RXD1/PS2',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='TXD1/PS3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='MISO0/PS4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='MOSI0/PS5',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='SCK0/PS6',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='SS0/PS7',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VREGEN',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='KWJ7/TXCAN4/SCL/TXCAN0/PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='KWJ6/RXCAN4/SDA/RXCAN0/PJ6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Regulator_Current = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'HV100K5-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV100K5-G'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-223-3_TabPin2'], 'footprint':'Package_TO_SOT_SMD:SOT-223-3_TabPin2', 'keywords':'Hot-Swap Current Limiter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/hv100%20b060513.pdf', 'search_text':'/usr/share/kicad/symbols/Regulator_Current.kicad_sym\nHV100K5-G\n\nHot-Swap Current Limiter', 'pins':[
            Pin(num='1',name='VPP',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VNN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GATE',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV101K5-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV101K5-G'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-223-3_TabPin2', 'Package_TO_SOT_SMD:SOT-223-3_TabPin2'], 'footprint':'Package_TO_SOT_SMD:SOT-223-3_TabPin2', 'keywords':'Hot-Swap Current Limiter', 'description':'', 'datasheet':'http://www.supertex.com/pdf/datasheets/HV100.pdf', 'search_text':'/usr/share/kicad/symbols/Regulator_Current.kicad_sym\nHV101K5-G\n\nHot-Swap Current Limiter', 'pins':[
            Pin(num='1',name='VPP',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VNN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GATE',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Jumper = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'Jumper_2_Bridged', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Jumper_2_Bridged'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'Jumper SPST', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nJumper_2_Bridged\n\nJumper SPST', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Jumper_2_Open', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Jumper_2_Open'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'Jumper SPST', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nJumper_2_Open\n\nJumper SPST', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Jumper_2_Small_Bridged', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Jumper_2_Small_Bridged'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'Jumper SPST', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nJumper_2_Small_Bridged\n\nJumper SPST', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Jumper_2_Small_Open', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Jumper_2_Small_Open'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'Jumper SPST', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nJumper_2_Small_Open\n\nJumper SPST', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Jumper_3_Bridged12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Jumper_3_Bridged12'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'Jumper SPDT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nJumper_3_Bridged12\n\nJumper SPDT', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Jumper_3_Open', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Jumper_3_Open'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'Jumper SPDT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nJumper_3_Open\n\nJumper SPDT', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SolderJumper_2_Bridged', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SolderJumper_2_Bridged'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'solder jumper SPST', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nSolderJumper_2_Bridged\n\nsolder jumper SPST', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SolderJumper_2_Open', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SolderJumper_2_Open'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'solder jumper SPST', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nSolderJumper_2_Open\n\nsolder jumper SPST', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SolderJumper_3_Bridged12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SolderJumper_3_Bridged12'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'Solder Jumper SPDT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nSolderJumper_3_Bridged12\n\nSolder Jumper SPDT', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SolderJumper_3_Bridged123', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SolderJumper_3_Bridged123'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'Solder Jumper SPDT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nSolderJumper_3_Bridged123\n\nSolder Jumper SPDT', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SolderJumper_3_Open', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SolderJumper_3_Open'}), 'ref_prefix':'JP', 'fplist':[''], 'footprint':'', 'keywords':'Solder Jumper SPDT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Jumper.kicad_sym\nSolderJumper_3_Open\n\nSolder Jumper SPDT', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Driver_TEC = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'MAX1968xUI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX1968xUI'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x5.4mm'], 'footprint':'Package_SO:HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x5.4mm', 'keywords':'thermoelectric cooler', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX1968-MAX1969.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_TEC.kicad_sym\nMAX1968xUI\n\nthermoelectric cooler', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='LX2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PVDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='FREQ',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ITEC',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OS2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OS1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PVDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='LX1',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PVDD1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='LX1',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='LX1',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='MAXIN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='MAXIP',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='MAXV',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CTLI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='LX2',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='LX2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PVDD2',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX1969xUI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX1969xUI'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x5.4mm', 'Package_SO:HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x5.4mm'], 'footprint':'Package_SO:HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x5.4mm', 'keywords':'thermoelectric cooler', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX1968-MAX1969.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_TEC.kicad_sym\nMAX1969xUI\n\nthermoelectric cooler', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='LX2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PVDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='FREQ',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ITEC',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OS2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OS1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PVDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='LX1',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PVDD1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='LX1',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='LX1',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='MAXIN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='MAXIP',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='MAXV',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CTLI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='LX2',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='LX2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PVDD2',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])


# -*- coding: utf-8 -*-

# The MIT License (MIT) - Copyright (c) Dave Vandenbout.

"""
Constants used when generating schematics.
"""

# Constants for KiCad.
GRID = 50
PIN_LABEL_FONT_SIZE = 50
BOX_LABEL_FONT_SIZE = 50
BLK_INT_PAD = 2 * GRID
BLK_EXT_PAD = 2 * GRID
DRAWING_BOX_RESIZE = 100
HIER_TERM_SIZE = 50
